@@ -106,6 +106,18 @@ const gchar *   gva_mame_get_state_directory    (GError **error);
 #define gva_mame_supports_full_screen() \
         (gva_mame_has_config_value ("fullscreen"))
 
+/**
+ * gva_mame_supports_maximize:
+ *
+ * Returns %TRUE if the MAME executable that
+ * <emphasis>GNOME Video Arcade</emphasis> is configured to use
+ * supports a "maximize" option.
+ *
+ * Returns: %TRUE is MAME supports the "maximize" option
+ **/
+#define gva_mame_supports_maximize() \
+        (gva_mame_has_config_value ("maximize"))
+
 /**
  * gva_mame_supports_window:
  *
