@@ -1,4 +1,4 @@
-/* Copyright 2007 Matthew Barnes
+/* Copyright 2007, 2008 Matthew Barnes
  *
  * This file is part of GNOME Video Arcade.
  *
@@ -31,11 +31,13 @@
 G_BEGIN_DECLS
 
 void            gva_properties_init             (void);
+void            gva_properties_show_game        (const gchar *game);
 
 /* Signal Handlers */
 
 void            gva_properties_close_clicked_cb (GtkWindow *window,
                                                  GtkButton *button);
+void            gva_properties_show_cb          (GtkWindow *window);
 
 G_END_DECLS
 
